//
//  GFaNotificationConditionManageViewController.m
//
//  Copyright (c) 2014 ZENRIN DataCom CO., LTD. All Rights Reserved.
//

#import "GFaNotificationConditionManageViewController.h"

#import <libGeoFenceManager/GeoFenceManager.h>
#import "GFaInformationDescriptionViewController.h"
#import "GFaUtility.h"

@interface GFaNotificationConditionManageViewController () <UIAlertViewDelegate>

- (void)removeNotificationCondition_:(NSString *)removeNotificationID;
- (void)getNotificationCondition_:(NSString *)getNotificationID;

@end

@implementation GFaNotificationConditionManageViewController

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    
    if ( indexPath.section == 0 )
    {
        if ( indexPath.row == 1 )
        {
            NSString *title = @"通知条件削除";
            NSString *message = @"通知条件IDを入力して下さい";
            NSString *cancelButtonTitle = @"キャンセル";
            NSString *otherButtonTitle = @"OK";
            [GFaUtility showInputAlert:self title:title message:message text:@"" cancelButtonTitle:cancelButtonTitle otherButtonTitle:otherButtonTitle keyboardType:UIKeyboardTypeDefault otherHandler:^(NSString *text) {
                [self removeNotificationCondition_:text];
            }];
        }
        else if ( indexPath.row == 2 )
        {
            NSString *title = @"通知条件取得";
            NSString *message = @"通知条件IDを入力して下さい.\nすべて取得する場合は,空欄のままOKを押して下さい.";
            NSString *cancelButtonTitle = @"キャンセル";
            NSString *otherButtonTitle = @"OK";
            [GFaUtility showInputAlert:self title:title message:message text:@"" cancelButtonTitle:cancelButtonTitle otherButtonTitle:otherButtonTitle keyboardType:UIKeyboardTypeDefault otherHandler:^(NSString *text) {
                [self getNotificationCondition_:text];
            }];
        }
    }
}

#pragma mark Private

- (void)removeNotificationCondition_:(NSString *)removeNotificationID
{
    NSNumber *notificationID = @(removeNotificationID.integerValue);
    
    NSString *title = nil;
    NSString *mess = nil;
    GeoFenceManager *manager = [GeoFenceManager defaultManager];
    if ( removeNotificationID.length > 0
        && [manager removeNotificationConditionInformation:@[notificationID]].count > 0 )
    {
        title = @"削除成功";
    }
    else
    {
        title = @"削除失敗";
        mess = [NSString stringWithFormat:@"通知条件を削除できませんでした\n(通知条件ID: %@)", removeNotificationID];
    }
    
    [GFaUtility showInformationAlert:self title:title message:mess];
}

- (void)getNotificationCondition_:(NSString *)getNotificationID
{
    GeoFenceManager *manager = [GeoFenceManager defaultManager];
    NSArray *info = nil;
    if ( getNotificationID.length > 0 )
    {
        /* 指定して取得する場合 */
        info = [manager notificationConditionInformationList:@[@(getNotificationID.integerValue)]];
    }
    else
    {
        /* すべて取得する場合 */
        info = [manager notificationConditionInformationList:nil];
    }
    
    if ( info.count > 0 )
    {
        /* 取得できた */
        GFaInformationDescriptionViewController *vc =
        [[GFaInformationDescriptionViewController alloc] initWithNibName:@"GFaInformationDescriptionViewController" bundle:nil];
        vc.title = @"通知条件表示";
        vc.descriptionInfo = info;
        GFaAssert(vc);
        [self.navigationController pushViewController:vc animated:YES];
    }
    else
    {
        /* 該当なし */
        [GFaUtility showInformationAlert:self title:@"該当する通知条件はありません" message:@""];
    }
}

@end
